==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/DataLegendSummaryEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSummaryEventArgsDescription } from "./DataLegendSummaryEventArgsDescription";
/**
 * @hidden
 */
export let DataLegendSummaryEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendSummaryEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendSummaryEventArgsDescriptionMetadata.a == null) {
                DataLegendSummaryEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendSummaryEventArgsDescriptionMetadata.c(DataLegendSummaryEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataLegendSummaryEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ColumnValues", "Array:double");
            a.item("ColumnMemberPath", "String");
            a.item("SummaryValue", "Number:double");
            a.item("SummaryUnits", "String");
            a.item("SummaryLabel", "String");
        }
        static d(a) {
            DataLegendSummaryEventArgsDescriptionMetadata.b(a);
            a.ad("DataLegendSummaryEventArgs", () => new DataLegendSummaryEventArgsDescription());
            a.ac("DataLegendSummaryEventArgs", DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
    }
    DataLegendSummaryEventArgsDescriptionMetadata.$t = markType(DataLegendSummaryEventArgsDescriptionMetadata, 'DataLegendSummaryEventArgsDescriptionMetadata');
    DataLegendSummaryEventArgsDescriptionMetadata.a = null;
    return DataLegendSummaryEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/DataLegendSummaryEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSummaryEventArgsDescription } from "./DataLegendSummaryEventArgsDescription";
/**
 * @hidden
 */
export let DataLegendSummaryEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendSummaryEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendSummaryEventArgsDescriptionMetadata.a == null) {
                DataLegendSummaryEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendSummaryEventArgsDescriptionMetadata.c(DataLegendSummaryEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataLegendSummaryEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ColumnValues", "Array:double");
            a.item("ColumnMemberPath", "String");
            a.item("SummaryValue", "Number:double");
            a.item("SummaryUnits", "String");
            a.item("SummaryLabel", "String");
        }
        static d(a) {
            DataLegendSummaryEventArgsDescriptionMetadata.b(a);
            a.ae("DataLegendSummaryEventArgs", () => new DataLegendSummaryEventArgsDescription());
            a.ad("DataLegendSummaryEventArgs", DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
    }
    DataLegendSummaryEventArgsDescriptionMetadata.$t = markType(DataLegendSummaryEventArgsDescriptionMetadata, 'DataLegendSummaryEventArgsDescriptionMetadata');
    DataLegendSummaryEventArgsDescriptionMetadata.a = null;
    return DataLegendSummaryEventArgsDescriptionMetadata;
})();
